import { EscrowClient } from '..';
import { MemberController } from './Member.js';
import { ProfileController } from './Profile.js';
import { SignatureController } from './Signature.js';
import { ContractCreate, ContractData, EndorseData, ProfileData, SignatureData } from '../schema/index.js';
interface ContractConfig {
    init_data?: ContractData;
    cache_exp: number;
}
export declare class EscrowContract {
    static create(client: EscrowClient, template: ContractCreate): Promise<EscrowContract>;
    readonly _cid: string;
    readonly _client: EscrowClient;
    readonly config: ContractConfig;
    _cache?: ContractData;
    refreshed_at?: Date;
    constructor(client: EscrowClient, contractId: string, config?: Partial<ContractConfig>);
    get cid(): string;
    get API(): import("../routes/contract").ContractRouter;
    get pubkey(): string;
    get data(): Promise<ContractData>;
    get endorsements(): Promise<EndorseData[]>;
    get members(): Promise<string[]>;
    get profiles(): Promise<ProfileData[]>;
    get signatures(): Promise<SignatureData[]>;
    cache(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        info: {
            title: string;
            admin: string;
            agent: string;
            description?: string | undefined;
            terms?: string | undefined;
        };
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        room: {
            secret: string;
            nonce?: string | undefined;
            pubkey?: string | undefined;
            hash?: string | undefined;
        };
        members: string[];
        contract_id: string;
        revision: number;
        created_at: Date;
        endorsements: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }[];
        profiles: {
            pubkey: string;
            updated_at: Date;
            nonce: string;
            alias: string;
        }[];
        records: {
            pubkey: string;
            kind: "data" | "script" | "term";
            label: string;
            content: string[];
            updated_at: Date;
        }[];
        signatures: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[];
        transactions: string[];
    }>;
    fetch(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        info: {
            title: string;
            admin: string;
            agent: string;
            description?: string | undefined;
            terms?: string | undefined;
        };
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        room: {
            secret: string;
            nonce?: string | undefined;
            pubkey?: string | undefined;
            hash?: string | undefined;
        };
        members: string[];
        contract_id: string;
        revision: number;
        created_at: Date;
        endorsements: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            signature: string;
        }[];
        profiles: {
            pubkey: string;
            updated_at: Date;
            nonce: string;
            alias: string;
        }[];
        records: {
            pubkey: string;
            kind: "data" | "script" | "term";
            label: string;
            content: string[];
            updated_at: Date;
        }[];
        signatures: {
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[];
        transactions: string[];
    }>;
    member: MemberController;
    profile: ProfileController;
    signature: SignatureController;
}
export {};
//# sourceMappingURL=Contract.d.ts.map